The Joker [YO-ker]
==================

.. image:: https://img.shields.io/badge/Made%20at-%23AstroHackWeek-8063d5.svg?style=flat
        :target: http://astrohackweek.org/
.. image:: http://img.shields.io/travis/adrn/thejoker/master.svg?style=flat
        :target: http://travis-ci.org/adrn/thejoker
.. image:: https://coveralls.io/repos/github/adrn/thejoker/badge.svg?branch=master
        :target: https://coveralls.io/github/adrn/thejoker?branch=master

A custom Monte Carlo sampler for the two-body problem.

Authors
-------

- **Adrian Price-Whelan** (Princeton)
- **David W. Hogg** (NYU, MPIA, & Flatiron)
- **Dan Foreman-Mackey** (UW)

Attribution
-----------

.. image:: http://img.shields.io/badge/arXiv-1610.07602-orange.svg?style=flat
        :target: https://arxiv.org/abs/1610.07602
.. image:: https://img.shields.io/badge/ascl-1701.001-blue.svg?colorB=262255
        :target: http://ascl.net/1701.001
.. image:: https://zenodo.org/badge/67356932.svg
        :target: https://zenodo.org/badge/latestdoi/67356932

If you make use of this code, please cite both the paper describing the method,
and the Zenodo DOI |DOI| as a software citation::

    @misc{Price-Whelan:2017a,
      author       = {Adrian Price-Whelan and
                      David W. Hogg},
      title        = {adrn/thejoker: Release v0.1},
      month        = jan,
      year         = 2017,
      doi          = {10.5281/zenodo.264481},
      url          = {https://doi.org/10.5281/zenodo.264481}
    }

    @ARTICLE{Price-Whelan:2017b,
       author = {{Price-Whelan}, A.~M. and {Hogg}, D.~W. and
                 {Foreman-Mackey}, D. and {Rix}, H.-W.},
        title = "{The Joker: A Custom Monte Carlo Sampler for Binary-star and
                  Exoplanet Radial Velocity Data}",
        journal = {\apj},
        archivePrefix = "arXiv",
        eprint = {1610.07602},
        primaryClass = "astro-ph.SR",
        keywords = {binaries: spectroscopic, methods: data analysis,
                    methods: statistical, planets and satellites: fundamental
                    parameters, surveys, techniques: radial velocities},
        year = 2017,
        month = mar,
        volume = 837,
        eid = {20},
        pages = {20},
        doi = {10.3847/1538-4357/aa5e50},
        adsurl = {http://adsabs.harvard.edu/abs/2017ApJ...837...20P},
        adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }

Documentation
-------------

.. image:: https://readthedocs.org/projects/thejoker/badge/?version=latest
        :target: http://thejoker.readthedocs.io/

See `the documentation <http://thejoker.readthedocs.io>`_ for information on how
to install and use The Joker.

License
-------

.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
        :target: https://github.com/adrn/thejoker/blob/master/LICENSE
